re###################################################
#                     XD-Spres                    #
#    Cross-dispersed Spectra Reduction Package    #
###################################################
#                     DOOSIRIS                    #
###################################################
# This is script was developed and written by     #
# Daniel Ruschel Dutra, at Universidade Federal   #
# do Rio Grande do Sul - Brazil.                  #
# If you have any doubts or suggestions please    #
# write to: daniel.ruschel@ufrgs.br               #
###################################################

procedure doosiris (prefix)

   string prefix   	{prompt="Image name prefix"}
   string outpre   	{prompt="Output image name prefix"}
   bool   lsc           {prompt="Linearize, subtract and combine science exposures?"}
   bool   inter		{prompt="Perform extraction interactively?"}
   int    num1     	{prompt="First image number"}
   int    num2     	{prompt="Last image number"}
   string objseq  	{prompt="File containing the sequence of object/sky images"}
   string apid="xdspres$xdap.tab" {prompt="Aperture identification table"}
   string nflat   	{prompt="Normalized flat image"}
   string skyim   	{prompt="Output name for sky image"}
   bool   id=yes  	{prompt="Identify OH lines interactively?"}
   string refskyj 	{prompt="Reference image for OH line identification (J band)"}
   string refskyh 	{prompt="Reference image for OH line identification (H band)"}
   string refskyk 	{prompt="Reference image for OH line identification (K band)"}
   string linelis="xdspres$ohlines.dat"  {prompt="File containing the OH lines list"}
   string statm="xdspres$"  {prompt="Path to the star atmospheric models"}
   int    starn1   	{prompt="First star image number"}
   int    starn2   	{prompt="Last star image number"}
   string seqstar  	{prompt="Sequence of star images"}
   string star     	{prompt="Star output prefix"}
   bool   inters=no     {prompt="Extract star spectra interactively?"}
   real   jmag     	{prompt="Star's J magnitude"}
   real   hmag     	{prompt="Star's H magnitude"}
   real   kmag     	{prompt="Star's K magnitude"}

begin

   string zeros
   string azer
   string bzer
   real expto
   real expts
   real szobj
   real szstar
   int c1
   expto = 0.
   expts = 0.
   szobj = 0.
   szstar = 0.
   c1 = 1

#loading packages

   noao
   imred
   irred
   crutil
   onedspec
   ccdred
   imred
   twodspec
   apextract
   images
   imutil

   x=0.
   y=0.
   j=0
   s1=""
   s2=""
   s3=""

#This next lines read the parameter secz from the image header for later use
#in the standard task. Since the images are going to be summed, there is an
#averaging operation at the end.

   for(i = num1; i <= num2; i+=1){

      if(i<10){zeros="000"}
      if(i>=10){
         if(i<100){zeros="00"}}
      if(i>=100){
         if(i<1000){zeros="0"}}
      if(i>=1000){zeros=""}

      if(access(prefix//zeros//i//".fits")){
         hselect (prefix//zeros//i, "secz", "yes") | scan x
         j=j+1
         y=y+x}
      else {print ("WARNING! File ", prefix//zeros//i//".fits", " not found.")}
      }

   szobj = y/j

   x=0.
   y=0.
   j=0

   for(i = starn1; i <= starn2; i+=1){

      if(i<10){zeros="000"}
      if(i>=10){
         if(i<100){zeros="00"}}
      if(i>=100){
         if(i<1000){zeros="0"}}
      if(i>=1000){zeros=""}

      hselect (prefix//zeros//i, "secz", "yes") | scan x
      j=j+1
      y=y+x
   }

   szstar = y/j

if(lsc){

#Correcting for the non-linear behaviour of the detector. The coefficients used
#are those found in the OSIRIS manual.
#http://www.ctio.noao.edu/instruments/ir_instruments/osiris2soar/manual/array.html
#Before the correction is applied the script will look for the key LINCOR in the image
#header, and if it is set to "yes" the correction will not be applied, so that you
#will not incur in the mistake of correcting twice the same image.
#
# coeff1 = 1.00108
# coeff2 = -3.328396e-2
# coeff3 = 0.166216
# coeff4 = -6.844057e-2
#
# adu'/adu = 1.00108 - 1.015777e-6*adu + 1.548099e-10*adu**2 - 1.94537e-15*adu**3
#

   for(i=num1; i <= num2; i+=1){
   
      if(i<10){zeros="000"}
      if(i>=10){
         if(i<100){zeros="00"}}
      if(i>=100){
         if(i<1000){zeros="0"}}
      if(i>=1000){zeros=""}

   hselect (prefix//zeros//i, "lincor", "yes") | scan s3
   if(s3 != "yes"){
   irlincor (input=prefix//zeros//i, output=prefix//zeros//i, coeff1=1.00108,
      coeff2=-3.328396e-2, coeff3=0.166216, coeff4=-6.844057e-02)
   hedit (prefix//zeros//i, "lincor", "yes", add=yes, addonly=yes, delete=no,
      verify=no, show=yes, update=yes)}
   }



#Next, the images are going to be copied after their content: "a" for object
#exposures and "b" for sky exposures. Also, the exposure time is read from
#the image header.

   if(access(objseq)){
   
   list = objseq
   
   x=0.

   for(i = num1; i <= num2; i+=1){
   
      if(i<10){zeros="000"}
      if(i>=10){
         if(i<100){zeros="00"}}
      if(i>=100){
         if(i<1000){zeros="0"}}
      if(i>=1000){zeros=""}

      if(access(prefix//zeros//i//".fits")){
         s2=fscan(list, s1)
	 imcopy (prefix//zeros//i, outpre//i//s1)
	    if(s1 == "a"){
	       hselect (outpre//i//"a", "exptime", "yes") | scan x
               expto = expto + x}
         cosmicrays (outpre//i//s1,
            outpre//i//s1, "yes", crmasks="", threshold=25., fluxratio=11., npasses=10,
            window="7", interactive=no, train=no, objects="", savefile="", plotfile="",
            graphics="stdgraph", cursor="")}
      else {print ("WARNING! File ", prefix//zeros//i//".fits", " not found.")}
   }
   }

   else{

   print ("Check the image in ds9")
   print ("If it is an object exposure type 'a'.")
   print ("It it is a sky exposure type 'b'.")

   x=0.

   for(i = num1; i <= num2; i+=1){

      if(i<10){zeros="000"}
      if(i>=10){
         if(i<100){zeros="00"}}
      if(i>=100){
         if(i<1000){zeros="0"}}
      if(i>=1000){zeros=""}

      if(access(prefix//zeros//i//".fits")){
         display (prefix//zeros//i)
	  scan s1
         print (s1, >> outpre//".seq")
	  imcopy (prefix//zeros//i, outpre//i//s1)
	     if(s1 == "a"){
	        hselect (outpre//i//"a", "exptime", "yes") | scan x
               expto = expto + x}
               cosmicrays (outpre//i//s1,
                  outpre//i//s1, "yes", crmasks="", threshold=25., fluxratio=11., npasses=10,
                  window="7", interactive=no, train=no, objects="", savefile="", plotfile="",
                  graphics="stdgraph", cursor="")}
      else {print ("WARNING! File ", prefix//zeros//i//".fits", " not found.")}
   }
   }

#Now the sky spectra is going to be subtracted from the objecta spectra.

   c1=1

   for(i = num1; i <= num2; i+=1){
      if(access(outpre//i//"a.fits")){
         for(j = 1; j < 1000; j+=1){
	    k=i-j
	    if(access(outpre//k//"b.fits")){
	       imarith (outpre//i//"a", "-", outpre//k//"b", outpre//c1)
	       print (outpre//c1//".fits", >> "object.list")
               print (outpre//i//"a", " - ", outpre//k//"b", " = ", outpre//c1, >> "subtraction.log")
	       c1=c1+1
	       goto endsub}
	    k=i+j
	    if(access(outpre//k//"b.fits")){
	       imarith (outpre//i//"a", "-", outpre//k//"b", outpre//c1)
	       print (outpre//c1//".fits", >> "object.list")
               print (outpre//i//"a", " - ", outpre//k//"b", " = ", outpre//c1, >> "subtraction.log")
	       c1=c1+1
	       goto endsub}}}
   endsub:
   }

#Next the script creates two separate lists of files: one for the object spectra
#and one for the sky spectra.

   ls (outpre//"*b.fits", ">", "sky.list")
   ls (outpre//"*a.fits", ">", "a.list")

#The spectra is combined

   imcombine ("@"//"object.list", outpre//"sum", combine="sum", reject="minmax")
   imcombine ("@"//"sky.list", skyim,  combine="sum", reject="none")

#cleaning up

   delete ("@"//"object.list", verify=no)
   delete ("@"//"sky.list", verify=no)
   delete ("@"//"a.list", verify=no)   
   delete ("object.list", verify=no)
   delete ("sky.list", verify=no)
   delete ("a.list", verify=no)

#flat correction

   imarith (outpre//"sum", "/", nflat, outpre//"flat")

   x=0.

#Removing background from the sky exposure
#The order of the function is set to 1000 because there are some
#strangely illuminated lines with a very narrow profile that can
#later be mistaken for OH emission lines during the identification
#process.

   ccdproc (skyim,
      output=skyim//"bg", ccdtype="", max_cache=0, noproc=no, fixpix=no, overscan=yes,
      trim=no, zerocor=no, darkcor=no, flatcor=no, illumcor=no, fringecor=no,
      readcor=no, scancor=no, readaxis="line", fixfile="", biassec="[980:1024,*]",
      trimsec="", zero="", dark="", flat="", illum="", fringe="", minreplace=1.,
      scantype="shortscan", nscan=1, interactive=no, function="spline3",
      order=1000, sample="*", naverage=1, niterate=1, low_reject=3., high_reject=3.,
      grow=0.)

}

#extracting the object spectrum

   apdefault.lower = -40.0
   apdefault.upper = 40.0
   apdefault.apidtab = apid
   apedit.width = 80.0
   apedit.radius = 20.0

   apfind (outpre//"flat",
      3, apertures=" ", references="", interactive=inter, find=yes, recenter=no,
      resize=no, edit=no, line=500, nsum=20, minsep=100., maxsep=INDEF,
      order="increasing")

   aprecenter (outpre//"flat",
      apertures="", references="", interactive=inter, find=no, recenter=yes,
      resize=no, edit=no, line=500, nsum=20, aprecenter="", npeaks=INDEF, shift=no)

   apresize (outpre//"flat",
      apertures=" ", references="", interactive=inter, find=no, recenter=no,
      resize=yes, edit=no, line=500, nsum=20, llimit=-60., ulimit=60., ylevel=0.1,
      peak=yes, bkg=no, r_grow=0., avglimits=no)

   aptrace (outpre//"flat",
      apertures="1", references="", interactive=inter, find=no, recenter=no,
      resize=no, edit=no, trace=yes, fittrace=yes, line=500, nsum=10, step=10,
      nlost=3, function="legendre", order=2, sample="50:800", naverage=1,
      niterate=2, low_reject=2., high_reject=2., grow=0.)

   aptrace (outpre//"flat",
      apertures="2", references="", interactive=inter, find=no, recenter=no,
      resize=no, edit=no, trace=yes, fittrace=yes, line=500, nsum=10, step=10,
      nlost=3, function="legendre", order=2, sample="50:950", naverage=1,
      niterate=2, low_reject=2., high_reject=2., grow=0.)

   aptrace (outpre//"flat",
      apertures="3", references="", interactive=inter, find=no, recenter=no,
      resize=no, edit=no, trace=yes, fittrace=yes, line=500, nsum=10, step=10,
      nlost=3, function="legendre", order=2, sample="400:950", naverage=1,
      niterate=2, low_reject=2., high_reject=2., grow=0.)


   apall (outpre//"flat",
      3, output=outpre, apertures="", format="onedspec", references="",
      profiles="", interactive=inter, find=no, recenter=no, resize=no, edit=no,
      trace=no, fittrace=no, extract=yes, extras=yes, review=yes, line=INDEF,
      nsum=10, lower=-50., upper=50., apidtable="", b_function="chebyshev",
      b_order=1, b_sample="-10:-6,6:10", b_naverage=-3, b_niterate=0,
      b_low_reject=3., b_high_rejec=3., b_grow=0., width=80., radius=40.,
      threshold=0., minsep=100., maxsep=INDEF, order="increasing", aprecenter="",
      npeaks=INDEF, shift=yes, llimit=-50., ulimit=50., ylevel=0.3, peak=yes,
      bkg=no, r_grow=0., avglimits=no, t_nsum=10, t_step=10, t_nlost=20,
      t_function="legendre", t_order=3, t_sample="*", t_naverage=1, t_niterate=3,
      t_low_reject=2., t_high_rejec=2., t_grow=0., background="none", skybox=1,
      weights="none", pfit="fit1d", clean=no, saturation=INDEF, readnoise="0.",
      gain="1.", lsigma=4., usigma=4., nsubaps=1)

   imrename (outpre//".0001", outpre//"j")
   imrename (outpre//".0002", outpre//"h")
   imrename (outpre//".0003", outpre//"k")

#extracting the sky spectrum

   delete ("./database/aplast")
      if(access("./database/aplast")){
         print ("Failed to delete file aplast.")}
      else {
         print ("File aplast deleted succesfully")}

   apall (skyim//"bg",
      3, output=skyim, apertures="", format="onedspec", references=outpre//"flat",
      profiles="", interactive=yes, find=no, recenter=no, resize=no, edit=no,
      trace=no, fittrace=no, extract=yes, extras=yes, review=yes, line=400,
      nsum=10, lower=-50., upper=50., apidtable="", b_function="chebyshev",
      b_order=1, b_sample="-10:-6,6:10", b_naverage=-3, b_niterate=0,
      b_low_reject=3., b_high_rejec=3., b_grow=0., width=80., radius=40.,
      threshold=0., minsep=100., maxsep=INDEF, order="increasing", aprecenter="",
      npeaks=INDEF, shift=yes, llimit=-50., ulimit=50., ylevel=0.3, peak=yes,
      bkg=no, r_grow=0., avglimits=no, t_nsum=20, t_step=20, t_nlost=20,
      t_function="legendre", t_order=3, t_sample="*", t_naverage=1, t_niterate=3,
      t_low_reject=2., t_high_rejec=2., t_grow=0., background="none", skybox=1,
      weights="none", pfit="fit1d", clean=no, saturation=INDEF, readnoise="0.",
      gain="1.", lsigma=4., usigma=4., nsubaps=1)

   imrename (skyim//".0001", skyim//"j")
   imrename (skyim//".0002", skyim//"h")
   imrename (skyim//".0003", skyim//"k")

#Sky lines identification

   if (id) {

#Interactive version

   print ("Identify the OH lines in the sky spectra and fit a dispersion function.")

   identify (skyim//"j",
      "1", "1", section="middle line", database="database",
      coordlist=linelis, units="", nsum="10",
      match=-3., maxfeatures=50, zwidth=100., ftype="emission", fwidth=4.,
      cradius=5., threshold=0., minsep=4., function="legendre", order=4, sample="*",
      niterate=0, low_reject=3., high_reject=3., grow=0., autowrite=no,
      graphics="stdgraph", cursor="", aidpars="")

   identify (skyim//"h",

      "1", "1", section="middle line", database="database",
      coordlist=linelis, units="", nsum="10",
      match=-3., maxfeatures=50, zwidth=100., ftype="emission", fwidth=4.,
      cradius=5., threshold=0., minsep=4., function="legendre", order=4, sample="*",
      niterate=0, low_reject=3., high_reject=3., grow=0., autowrite=no,
      graphics="stdgraph", cursor="", aidpars="")

   identify (skyim//"k",
      "1", "1", section="middle line", database="database",
      coordlist=linelis, units="", nsum="10",
      match=-3., maxfeatures=50, zwidth=100., ftype="emission", fwidth=4.,
      cradius=5., threshold=0., minsep=4., function="legendre", order=4, sample="*",
      niterate=0, low_reject=3., high_reject=3., grow=0., autowrite=no,
      graphics="stdgraph", cursor="", aidpars="")
   }

#non-interactive version
#I reccomend double-checking the results later

   else {
   
      if(strldx("/",refskyj) == 0) {
   
         reidentify (refskyj,
            skyim//"j", "yes", " ", " ", interactive="yes", section="middle line",
            newaps=yes, override=yes, refit=yes, trace=no, step="10", nsum="10",
            shift="0.", search=0., nlost=0, cradius=10., threshold=0., addfeatures=no,
            coordlist=linelis, match=-3., maxfeatures=50, minsep=4.,
            database="database", logfiles="logfile", plotfile="", verbose=no,
            graphics="stdgraph", cursor="", aidpars="")
      }
      
      else {
         
         s1 = substr(refskyj,strldx("/",refskyj)+1,strldx(".",refskyj)-1)
         cp (substr(refskyj,1,strldx("/",refskyj))//"database/id"//s1, "./database/")
          
         reidentify (s1,
            skyim//"j", "yes", " ", " ", interactive="yes", section="middle line",
            newaps=yes, override=yes, refit=yes, trace=no, step="10", nsum="10",
            shift="0.", search=0., nlost=0, cradius=10., threshold=0., addfeatures=no,
            coordlist=linelis, match=-3., maxfeatures=50, minsep=4.,
            database="database", logfiles="logfile", plotfile="", verbose=no,
            graphics="stdgraph", cursor="", aidpars="")
	    
	   delete ("./database/id"//s1, verify=no)
      }

      if(strldx("/",refskyh) == 0) {
   
         reidentify (refskyh,
            skyim//"h", "yes", " ", " ", interactive="yes", section="middle line",
            newaps=yes, override=yes, refit=yes, trace=no, step="10", nsum="10",
            shift="0.", search=0., nlost=0, cradius=10., threshold=0., addfeatures=no,
            coordlist=linelis, match=-3., maxfeatures=50, minsep=4.,
            database="database", logfiles="logfile", plotfile="", verbose=no,
            graphics="stdgraph", cursor="", aidpars="")
      }
      
      else {
         
         s1 = substr(refskyh,strldx("/",refskyh)+1,strldx(".",refskyh)-1)
         cp (substr(refskyh,1,strldx("/",refskyh))//"database/id"//s1, "./database/")
          
         reidentify (s1,
            skyim//"h", "yes", " ", " ", interactive="yes", section="middle line",
            newaps=yes, override=yes, refit=yes, trace=no, step="10", nsum="10",
            shift="0.", search=0., nlost=0, cradius=10., threshold=0., addfeatures=no,
            coordlist=linelis, match=-3., maxfeatures=50, minsep=4.,
            database="database", logfiles="logfile", plotfile="", verbose=no,
            graphics="stdgraph", cursor="", aidpars="")
	    
	   delete ("./database/id"//s1, verify=no)
      }
      
      if(strldx("/",refskyk) == 0) {
   
         reidentify (refskyk,
            skyim//"k", "yes", " ", " ", interactive="yes", section="middle line",
            newaps=yes, override=yes, refit=yes, trace=no, step="10", nsum="10",
            shift="0.", search=0., nlost=0, cradius=10., threshold=0., addfeatures=no,
            coordlist=linelis, match=-3., maxfeatures=50, minsep=4.,
            database="database", logfiles="logfile", plotfile="", verbose=no,
            graphics="stdgraph", cursor="", aidpars="")
      }
      
      else {
         
         s1 = substr(refskyk,strldx("/",refskyk)+1,strldx(".",refskyk)-1)
         cp (substr(refskyk,1,strldx("/",refskyk))//"database/id"//s1, "./database/")
          
         reidentify (s1,
            skyim//"k", "yes", " ", " ", interactive="yes", section="middle line",
            newaps=yes, override=yes, refit=yes, trace=no, step="10", nsum="10",
            shift="0.", search=0., nlost=0, cradius=10., threshold=0., addfeatures=no,
            coordlist=linelis, match=-3., maxfeatures=50, minsep=4.,
            database="database", logfiles="logfile", plotfile="", verbose=no,
            graphics="stdgraph", cursor="", aidpars="")
	    
	   delete ("./database/id"//s1, verify=no)
	 
      }
      
   }

#applying dispersion function

   hedit (outpre//"j", "REFSPEC1", skyim//"j", add=yes, addonly=yes, delete=no,
         verify=no, show=yes, update=yes)
   hedit (outpre//"h", "REFSPEC1", skyim//"h", add=yes, addonly=yes, delete=no,
         verify=no, show=yes, update=yes)
   hedit (outpre//"k", "REFSPEC1", skyim//"k", add=yes, addonly=yes, delete=no,
         verify=no, show=yes, update=yes)

   dispcor (outpre//"j", outpre//"j_wl")
   dispcor (outpre//"h", outpre//"h_wl")
   dispcor (outpre//"k", outpre//"k_wl")

#####################################################################
#                                                                   #
# Aqui comecam as operacoes com a estrela que servira para calibrar #
# o espectro do aglomerado em fluxo.                                #
# No conjunto de dados recebido neste turno, as estrelas foram      #
# observadas ocupando tres posicoes diferentes sobre o CCD, logo    #
# aquela velha tatica de simplesmente subtrair as pares das impares #
# nao vai vingar. O codigo abaixo contempla esta nova organizacao.  #
#                                                                   #
#####################################################################

#####################################################################
#                                                                   #
# Here begin the operations with the star that will be used in the  #
# flux calibration                                                  #
# These operations assume that the star was observed occupying      #
# three different positions in the detector, and they will be       #
# subtracted accordingly.                                           #
#                                                                   #
#####################################################################

#applying linearity correction to the exposures star exposures.

   for(i=starn1; i <= starn2 ; i+=1){

      if(i<10){zeros="000"}
      if(i>=10){
         if(i<100){zeros="00"}}
      if(i>=100){
         if(i<1000){zeros="0"}}
      if(i>=1000){zeros=""}
   
      hselect (prefix//zeros//i, "lincor", "yes") | scan s3
      if(s3 != "yes"){
      irlincor (input=prefix//zeros//i, output=prefix//zeros//i, coeff1=1.00108,
         coeff2=-3.328396e-02, coeff3=0.166216, coeff4=-6.844057e-02)
      hedit (prefix//zeros//i, "lincor", "yes", add=yes, addonly=yes, delete=no,
         verify=no, show=yes, update=yes)}
   }

   if(seqstar == "abc"){

#subtracting the star exposures

#esta subtracao preve uma sequencia de tres posicoes diferentes da estrela: a, b e c.
#as operacoes sao: a - c, b - c, c - a.

#this subtraction assumes a sequence of three different positions a, b and c.
#the operations are: a - c, b - c, c - a.

   x=0

   for(i=starn1; i <= starn2-2; i+=3){
   
      if(i<10){zeros="000"}
      if(i>=10){
         if(i<100){zeros="00"}}
      if(i>=100){
         if(i<1000){zeros="0"}}
      if(i>=1000){zeros=""}

      azer=zeros
      bzer=zeros

      if(i==9){
         azer="00"
         bzer="00"}
      if(i==99){
         azer="0"
         bzer="0"}
      if(i==999){
         azer=""
         bzer=""}
      if(i==8){
         azer="000"
         bzer="00"}
      if(i==98){
         azer="00"
         bzer="0"}
      if(i==998){
         azer="0"
         bzer=""}
      
      imarith (prefix//zeros//i, "-", prefix//bzer//i+2, star//i)
      imarith (prefix//azer//i+1, "-", prefix//bzer//i+2, star//i+1)
      imarith (prefix//bzer//i+2, "-", prefix//azer//i, star//i+2)
      print (star//i//".fits", >> "star_a.list")
      print (star//i+1//".fits", >> "star_b.list")
      print (star//i+2//".fits", >> "star_c.list")
      hselect (prefix//zeros//i, "exptime", "yes") | scan x
      expts = expts + x
   }
   
#combining the star's 2D spectra

   imcombine ("@"//"star_a.list", star//"a_sum", combine="sum", reject="none")
   imcombine ("@"//"star_b.list", star//"b_sum", combine="sum", reject="none")
   imcombine ("@"//"star_c.list", star//"c_sum", combine="sum", reject="none")

#aplicando o flat-field nas exposicoes da estrela

#applying flat-field correction to the star exposures

   imarith (star//"a_sum", "/", nflat, star//"a_flat")
   imarith (star//"b_sum", "/", nflat, star//"b_flat")
   imarith (star//"c_sum", "/", nflat, star//"c_flat")

#cleaning up

   cat ("star_a.list", >> "lixo.list")
   cat ("star_b.list", >> "lixo.list")
   cat ("star_c.list", >> "lixo.list")
   print ("star_a.list", >> "lixo.list")
   print ("star_b.list", >> "lixo.list")
   print ("star_c.list", >> "lixo.list")
   delete ("@"//"lixo.list", verify=no)
   delete ("lixo.list", verify=no)

#extraindo as tres exposicoes A,B e C, da estrela.

#extracting the three exposures.

   apdefault.lower = -15.0
   apdefault.upper = 15.0
   apdefault.apidtab = apid
   apedit.width = 20
   apedit.radius = 20.0

   apresize.llimit=-20.0
   apresize.ulimit=20.0
   apresize.ylevel=0.2

   apfind (star//"a_flat",
      3, apertures=" ", references="", interactive=inter, find=yes, recenter=yes,
      resize=yes, edit=no, line=500, nsum=20, minsep=100., maxsep=INDEF,
      order="increasing")
        
   aptrace (star//"a_flat",
      apertures="1", references="", interactive=inter, find=no, recenter=no,
      resize=no, edit=no, trace=yes, fittrace=yes, line=500, nsum=10, step=10,
      nlost=3, function="legendre", order=2, sample="50:800", naverage=1,
      niterate=2, low_reject=2., high_reject=2., grow=0.)
      
   aptrace (star//"a_flat",
      apertures="2", references="", interactive=inter, find=no, recenter=no,
      resize=no, edit=no, trace=yes, fittrace=yes, line=500, nsum=10, step=10,
      nlost=3, function="legendre", order=2, sample="50:950", naverage=1,
      niterate=2, low_reject=2., high_reject=2., grow=0.)

   aptrace (star//"a_flat",
      apertures="3", references="", interactive=inter, find=no, recenter=no,
      resize=no, edit=no, trace=yes, fittrace=yes, line=500, nsum=10, step=10,
      nlost=3, function="legendre", order=2, sample="400:950", naverage=1,
      niterate=2, low_reject=2., high_reject=2., grow=0.)

   apall (star//"a_flat",
      3, output=star//"a", apertures="", format="onedspec", references="",
      profiles="", interactive=inter, find=no, recenter=no, resize=no, edit=no,
      trace=no, fittrace=no, extract=yes, extras=no, review=yes, line=INDEF,
      nsum=10, lower=-5., upper=5., apidtable="", b_function="chebyshev",
      b_order=1, b_sample="-10:-6,6:10", b_naverage=-3, b_niterate=0,
      b_low_reject=3., b_high_rejec=3., b_grow=0., width=6., radius=3.,
      threshold=0., minsep=100., maxsep=INDEF, order="increasing", aprecenter="",
      npeaks=INDEF, shift=yes, llimit=INDEF, ulimit=INDEF, ylevel=0.1, peak=yes,
      bkg=no, r_grow=0., avglimits=no, t_nsum=10, t_step=10, t_nlost=3,
      t_function="legendre", t_order=2, t_sample="*", t_naverage=1, t_niterate=3,
      t_low_reject=3., t_high_rejec=3., t_grow=0., background="none", skybox=1,
      weights="none", pfit="fit1d", clean=no, saturation=INDEF, readnoise="0.",
      gain="1.", lsigma=4., usigma=4., nsubaps=1)

###

   apfind (star//"b_flat",
      3, apertures=" ", references="", interactive=inter, find=yes, recenter=yes,
      resize=yes, edit=no, line=500, nsum=20, minsep=100., maxsep=INDEF,
      order="increasing")
        
   aptrace (star//"b_flat",
      apertures="1", references="", interactive=inter, find=no, recenter=no,
      resize=no, edit=no, trace=yes, fittrace=yes, line=500, nsum=10, step=10,
      nlost=3, function="legendre", order=2, sample="50:800", naverage=1,
      niterate=2, low_reject=2., high_reject=2., grow=0.)
      
   aptrace (star//"b_flat",
      apertures="2", references="", interactive=inter, find=no, recenter=no,
      resize=no, edit=no, trace=yes, fittrace=yes, line=500, nsum=10, step=10,
      nlost=3, function="legendre", order=2, sample="50:950", naverage=1,
      niterate=2, low_reject=2., high_reject=2., grow=0.)

   aptrace (star//"b_flat",
      apertures="3", references="", interactive=inter, find=no, recenter=no,
      resize=no, edit=no, trace=yes, fittrace=yes, line=500, nsum=10, step=10,
      nlost=3, function="legendre", order=2, sample="400:950", naverage=1,
      niterate=2, low_reject=2., high_reject=2., grow=0.)

   apall (star//"b_flat",
      3, output=star//"b", apertures="", format="onedspec", references="",
      profiles="", interactive=inter, find=no, recenter=no, resize=no, edit=no,
      trace=no, fittrace=no, extract=yes, extras=no, review=yes, line=INDEF,
      nsum=10, lower=-5., upper=5., apidtable="", b_function="chebyshev",
      b_order=1, b_sample="-10:-6,6:10", b_naverage=-3, b_niterate=0,
      b_low_reject=3., b_high_rejec=3., b_grow=0., width=6., radius=3.,
      threshold=0., minsep=100., maxsep=INDEF, order="increasing", aprecenter="",
      npeaks=INDEF, shift=yes, llimit=INDEF, ulimit=INDEF, ylevel=0.1, peak=yes,
      bkg=no, r_grow=0., avglimits=no, t_nsum=10, t_step=10, t_nlost=3,
      t_function="legendre", t_order=2, t_sample="*", t_naverage=1, t_niterate=3,
      t_low_reject=3., t_high_rejec=3., t_grow=0., background="none", skybox=1,
      weights="none", pfit="fit1d", clean=no, saturation=INDEF, readnoise="0.",
      gain="1.", lsigma=4., usigma=4., nsubaps=1)

###

   apfind (star//"c_flat",
      3, apertures=" ", references="", interactive=inter, find=yes, recenter=yes,
      resize=yes, edit=no, line=500, nsum=20, minsep=100., maxsep=INDEF,
      order="increasing")
        
   aptrace (star//"c_flat",
      apertures="1", references="", interactive=inter, find=no, recenter=no,
      resize=no, edit=no, trace=yes, fittrace=yes, line=500, nsum=10, step=10,
      nlost=3, function="legendre", order=2, sample="50:800", naverage=1,
      niterate=2, low_reject=2., high_reject=2., grow=0.)
      
   aptrace (star//"c_flat",
      apertures="2", references="", interactive=inter, find=no, recenter=no,
      resize=no, edit=no, trace=yes, fittrace=yes, line=500, nsum=10, step=10,
      nlost=3, function="legendre", order=2, sample="50:950", naverage=1,
      niterate=2, low_reject=2., high_reject=2., grow=0.)

   aptrace (star//"c_flat",
      apertures="3", references="", interactive=inter, find=no, recenter=no,
      resize=no, edit=no, trace=yes, fittrace=yes, line=500, nsum=10, step=10,
      nlost=3, function="legendre", order=2, sample="400:950", naverage=1,
      niterate=2, low_reject=2., high_reject=2., grow=0.)

   apall (star//"c_flat",
      3, output=star//"c", apertures="", format="onedspec", references="",
      profiles="", interactive=inter, find=no, recenter=no, resize=no, edit=no,
      trace=no, fittrace=no, extract=yes, extras=no, review=yes, line=INDEF,
      nsum=10, lower=-5., upper=5., apidtable="", b_function="chebyshev",
      b_order=1, b_sample="-10:-6,6:10", b_naverage=-3, b_niterate=0,
      b_low_reject=3., b_high_rejec=3., b_grow=0., width=6., radius=3.,
      threshold=0., minsep=100., maxsep=INDEF, order="increasing", aprecenter="",
      npeaks=INDEF, shift=yes, llimit=INDEF, ulimit=INDEF, ylevel=0.1, peak=yes,
      bkg=no, r_grow=0., avglimits=no, t_nsum=10, t_step=10, t_nlost=3,
      t_function="legendre", t_order=2, t_sample="*", t_naverage=1, t_niterate=3,
      t_low_reject=3., t_high_rejec=3., t_grow=0., background="none", skybox=1,
      weights="none", pfit="fit1d", clean=no, saturation=INDEF, readnoise="0.",
      gain="1.", lsigma=4., usigma=4., nsubaps=1)

#somando os espectros extraidos nas tres bandas

#summing the extracted spectra

   print (star//"a.0001", > "0001.list")
   print (star//"b.0001", >> "0001.list")
   print (star//"c.0001", >> "0001.list")

   print (star//"a.0002", > "0002.list")
   print (star//"b.0002", >> "0002.list")
   print (star//"c.0002", >> "0002.list")

   print (star//"a.0003", > "0003.list")
   print (star//"b.0003", >> "0003.list")
   print (star//"c.0003", >> "0003.list")

   imcombine ("@"//"0001.list", star//"j", combine="sum", reject="none")
   imcombine ("@"//"0002.list", star//"h", combine="sum", reject="none")
   imcombine ("@"//"0003.list", star//"k", combine="sum", reject="none")
   }

   if(seqstar == "ab"){

#Esta subtracao supoe que a estrela ocupa somente duas posicoes diferentes na fenda

#This subtraction assumes that the star was observed in two different positions along the slit

   
   x=0

   for(i=starn1; i <= starn2-1; i+=2){
   
      if(i<10){zeros="000"}
      if(i>=10){
         if(i<100){zeros="00"}}
      if(i>=100){
         if(i<1000){zeros="0"}}
      if(i>=1000){zeros=""}

      azer=zeros
      bzer=zeros

      if(i==9){
         azer="00"
         bzer="00"}
      if(i==99){
         azer="0"
         bzer="0"}
      if(i==999){
         azer=""
         bzer=""}

      imarith (prefix//zeros//i, "-", prefix//azer//i+1, star//i)
      imarith (star//i, "*", "-1", star//i+1)
      print (star//i//".fits", >> "star_a.list")
      print (star//i+1//".fits", >> "star_b.list")
      hselect (prefix//zeros//i, "exptime", "yes") | scan x
      expts = expts + x
   }

#combinando as exposicoes da estrela

#combining the star's exposures

   imcombine ("@"//"star_a.list", "star_a.fits", combine="sum", reject="none")
   imcombine ("@"//"star_b.list", "star_b.fits", combine="sum", reject="none")

#aplicando o flat-field

#flatfielding images

   imarith ("star_a", "/", nflat, star//"a_flat")
   imarith ("star_b", "/", nflat, star//"b_flat")
   
#cleaning up

   cat ("star_a.list", >> "lixo.list")
   cat ("star_b.list", >> "lixo.list")
   print ("star_a.list", >> "lixo.list")
   print ("star_b.list", >> "lixo.list")
   delete ("@"//"lixo.list", verify=no)
   delete ("lixo.list", verify=no)

#extraindo as exposicoes da estrela http://www.ctio.noao.edu/instruments/ir_instruments/osiris2soar/manual/xdskyJ.eps

#extracting the star

   apfind (star//"a_flat",
      3, apertures=" ", references="", interactive=inter, find=yes, recenter=yes,
      resize=yes, edit=no, line=500, nsum=20, minsep=100., maxsep=INDEF,
      order="increasing")
        
   aptrace (star//"a_flat",
      apertures="1", references="", interactive=inter, find=no, recenter=no,
      resize=no, edit=no, trace=yes, fittrace=yes, line=500, nsum=10, step=10,
      nlost=3, function="legendre", order=2, sample="50:800", naverage=1,
      niterate=2, low_reject=2., high_reject=2., grow=0.)
      
   aptrace (star//"a_flat",
      apertures="2", references="", interactive=inter, find=no, recenter=no,
      resize=no, edit=no, trace=yes, fittrace=yes, line=500, nsum=10, step=10,
      nlost=3, function="legendre", order=2, sample="50:950", naverage=1,
      niterate=2, low_reject=2., high_reject=2., grow=0.)

   aptrace (star//"a_flat",
      apertures="3", references="", interactive=inter, find=no, recenter=no,
      resize=no, edit=no, trace=yes, fittrace=yes, line=500, nsum=10, step=10,
      nlost=3, function="legendre", order=2, sample="400:950", naverage=1,
      niterate=2, low_reject=2., high_reject=2., grow=0.)

   apall (star//"a_flat",
      3, output=star//"a", apertures="", format="onedspec", references="",
      profiles="", interactive=inter, find=no, recenter=no, resize=no, edit=no,
      trace=no, fittrace=no, extract=yes, extras=no, review=yes, line=INDEF,
      nsum=10, lower=-5., upper=5., apidtable="", b_function="chebyshev",
      b_order=1, b_sample="-10:-6,6:10", b_naverage=-3, b_niterate=0,
      b_low_reject=3., b_high_rejec=3., b_grow=0., width=5., radius=10.,
      threshold=0., minsep=5., maxsep=1000., order="increasing", aprecenter="",
      npeaks=INDEF, shift=yes, llimit=INDEF, ulimit=INDEF, ylevel=0.1, peak=yes,
      bkg=no, r_grow=0., avglimits=no, t_nsum=10, t_step=10, t_nlost=3,
      t_function="legendre", t_order=2, t_sample="*", t_naverage=1, t_niterate=3,
      t_low_reject=3., t_high_rejec=3., t_grow=0., background="none", skybox=1,
      weights="none", pfit="fit1d", clean=no, saturation=INDEF, readnoise="0.",
      gain="1.", lsigma=4., usigma=4., nsubaps=1)

###

   apfind (star//"b_flat",
      3, apertures=" ", references="", interactive=inter, find=yes, recenter=yes,
      resize=yes, edit=no, line=500, nsum=20, minsep=100., maxsep=INDEF,
      order="increasing")
        
   aptrace (star//"b_flat",
      apertures="1", references="", interactive=inter, find=no, recenter=no,
      resize=no, edit=no, trace=yes, fittrace=yes, line=500, nsum=10, step=10,
      nlost=3, function="legendre", order=2, sample="50:800", naverage=1,
      niterate=2, low_reject=2., high_reject=2., grow=0.)
      
   aptrace (star//"b_flat",
      apertures="2", references="", interactive=inter, find=no, recenter=no,
      resize=no, edit=no, trace=yes, fittrace=yes, line=500, nsum=10, step=10,
      nlost=3, function="legendre", order=2, sample="50:950", naverage=1,
      niterate=2, low_reject=2., high_reject=2., grow=0.)

   aptrace (star//"b_flat",
      apertures="3", references="", interactive=inter, find=no, recenter=no,
      resize=no, edit=no, trace=yes, fittrace=yes, line=500, nsum=10, step=10,
      nlost=3, function="legendre", order=2, sample="400:1000", naverage=1,
      niterate=2, low_reject=2., high_reject=2., grow=0.)

   apall (star//"b_flat",
      3, output=star//"b", apertures="", format="onedspec", references="",
      profiles="", interactive=inter, find=no, recenter=no, resize=no, edit=no,
      trace=no, fittrace=no, extract=yes, extras=no, review=yes, line=INDEF,
      nsum=10, lower=-5., upper=5., apidtable="", b_function="chebyshev",
      b_order=1, b_sample="-10:-6,6:10", b_naverage=-3, b_niterate=0,
      b_low_reject=3., b_high_rejec=3., b_grow=0., width=5., radius=10.,
      threshold=0., minsep=5., maxsep=1000., order="increasing", aprecenter="",
      npeaks=INDEF, shift=yes, llimit=INDEF, ulimit=INDEF, ylevel=0.1, peak=yes,
      bkg=no, r_grow=0., avglimits=no, t_nsum=10, t_step=10, t_nlost=3,
      t_function="legendre", t_order=2, t_sample="*", t_naverage=1, t_niterate=3,
      t_low_reject=3., t_high_rejec=3., t_grow=0., background="none", skybox=1,
      weights="none", pfit="fit1d", clean=no, saturation=INDEF, readnoise="0.",
      gain="1.", lsigma=4., usigma=4., nsubaps=1)

#somando os espectros extraidos

#summing extracted spectra

   print (star//"a.0001", > "0001.list")
   print (star//"b.0001", >> "0001.list")

   print (star//"a.0002", > "0002.list")
   print (star//"b.0002", >> "0002.list")

   print (star//"a.0003", > "0003.list")
   print (star//"b.0003", >> "0003.list")

   imcombine ("@"//"0001.list", star//"j", combine="sum", reject="none")
   imcombine ("@"//"0002.list", star//"h", combine="sum", reject="none")
   imcombine ("@"//"0003.list", star//"k", combine="sum", reject="none")
   }

#aplicando funcao de dispersao a estrela

#applying the dispersion function

   hedit (star//"j", "REFSPEC1", skyim//"j", add=yes, addonly=no, delete=no,
         verify=no, show=yes, update=yes)
   hedit (star//"h", "REFSPEC1", skyim//"h", add=yes, addonly=no, delete=no,
         verify=no, show=yes, update=yes)
   hedit (star//"k", "REFSPEC1", skyim//"k", add=yes, addonly=no, delete=no,
         verify=no, show=yes, update=yes)

   dispcor (star//"j", star//"j_wl")
   dispcor (star//"h", star//"h_wl")
   dispcor (star//"k", star//"k_wl")

#cortando as imagens

#cutting the images

   scopy (star//"j_wl",
      star//"j_cut", w1=12000., w2=15000., apertures="1", bands="", beams="", 
      apmodulus=0, format="multispec", renumber=no, offset=0, clobber=no,
      merge=no, rebin=yes, verbose=no)

   scopy (star//"h_wl",
      star//"h_cut", w1=15000., w2=19000., apertures="2", bands="", beams="", 
      apmodulus=0, format="multispec", renumber=no, offset=0, clobber=no,
      merge=no, rebin=yes, verbose=no)

   scopy (star//"k_wl",
      star//"k_cut", w1=19000., w2=23500., apertures="3", bands="", beams="", 
      apmodulus=0, format="multispec", renumber=no, offset=0, clobber=no,
      merge=no, rebin=yes, verbose=no)

   scopy (outpre//"j_wl",
      outpre//"j_cut", w1=12000., w2=15000., apertures="1", bands="", beams="", 
      apmodulus=0, format="multispec", renumber=no, offset=0, clobber=no,
      merge=no, rebin=yes, verbose=no)

   scopy (outpre//"h_wl",
      outpre//"h_cut", w1=15000., w2=19000., apertures="2", bands="", beams="", 
      apmodulus=0, format="multispec", renumber=no, offset=0, clobber=no,
      merge=no, rebin=yes, verbose=no)

   scopy (outpre//"k_wl",
      outpre//"k_cut", w1=19000., w2=23500., apertures="3", bands="", beams="", 
      apmodulus=0, format="multispec", renumber=no, offset=0, clobber=no,
      merge=no, rebin=yes, verbose=no)

#removendo as linhas da atmosfera estelar

#removing the star's atmospheric lines

#A shor word for the user.

#removing the star's atmospheric lines 

   telluric (star//"j_cut",
      star//"j_clean", statm//"standard_atm_j", 1, "yes", ignoreaps=no, xcorr=yes,
      tweakrms=yes, interactive=yes, sample="*", threshold=.1, lag=10, shift=0.,
      scale=1., dshift=0.1, dscale=0.1, offset=1., smooth=1, cursor="")

   telluric (star//"h_cut",
      star//"h_clean", statm//"standard_atm_h", 1, "yes", ignoreaps=no, xcorr=yes,
      tweakrms=yes, interactive=yes, sample="*", threshold=.1, lag=10, shift=0.,
      scale=1., dshift=0.1, dscale=0.1, offset=1., smooth=1, cursor="")

   telluric (star//"k_cut",
      star//"k_clean", statm//"standard_atm_k", 1, "yes", ignoreaps=no, xcorr=yes,
      tweakrms=yes, interactive=yes, sample="*", threshold=.1, lag=10, shift=0.,
      scale=1., dshift=0.1, dscale=0.1, offset=1., smooth=1, cursor="")

#normalizing the standard star spectra

   continuum (star//"j_clean",
      "tell_j", "yes", lines="*", bands="1", type="ratio", replace=no, wavescale=yes,
      logscale=no, override=no, listonly=no, logfiles="logfile", interactive=no,
      sample="12200:12500,12800:12960,14950:15000", naverage=1, function="legendre", order=5, low_reject=1.,
      high_reject=0., niterate=10, grow=1., markrej=yes, graphics="stdgraph",
      cursor="")

   continuum (star//"j_clean",
      "blackbody_j", "yes", lines="*", bands="1", type="fit", replace=no, wavescale=yes,
      logscale=no, override=no, listonly=no, logfiles="logfile", interactive=no,
      sample="12200:12500,12800:12960,14950:15000", naverage=1, function="legendre", order=5, low_reject=1.,
      high_reject=0., niterate=10, grow=1., markrej=yes, graphics="stdgraph",
      cursor="")


   continuum (star//"h_clean",
      "tell_h", "yes", lines="*", bands="1", type="ratio", replace=no, wavescale=yes,
      logscale=no, override=no, listonly=no, logfiles="logfile", interactive=no,
      sample="15000:15650,15860:15960,16150:17200", naverage=1, function="legendre", order=5, low_reject=1.,
      high_reject=0., niterate=10, grow=1., markrej=yes, graphics="stdgraph",
      cursor="")

   continuum (star//"h_clean",
      "blackbody_h", "yes", lines="*", bands="1", type="fit", replace=no, wavescale=yes,
      logscale=no, override=no, listonly=no, logfiles="logfile", interactive=no,
      sample="15000:15650,15860:15960,16150:17200", naverage=1, function="legendre", order=5, low_reject=1.,
      high_reject=0., niterate=10, grow=1., markrej=yes, graphics="stdgraph",
      cursor="")

   continuum (star//"k_clean",
      "tell_k", "yes", lines="*", bands="1", type="ratio", replace=no, wavescale=yes,
      logscale=no, override=no, listonly=no, logfiles="logfile", interactive=no,
      sample="20280:20440,21800:22160,19750:19980,23060:23150", naverage=1, function="legendre", order=5, low_reject=1.,
      high_reject=0., niterate=10, grow=1., markrej=yes, graphics="stdgraph",
      cursor="")

   continuum (star//"k_clean",
      "blackbody_k", "yes", lines="*", bands="1", type="fit", replace=no, wavescale=yes,
      logscale=no, override=no, listonly=no, logfiles="logfile", interactive=no,
      sample="20280:20440,21800:22160,19750:19980,23060:23150", naverage=1, function="legendre", order=5, low_reject=1.,
      high_reject=0., niterate=10, grow=1., markrej=yes, graphics="stdgraph",
      cursor="")


#criando imagens blackbody

#creating the blackbody images that will be used in the standard task

#   imarith (star//"j_clean", "/", "tell_j", "blackbody_j")
#   imarith (star//"h_clean", "/", "tell_h", "blackbody_h")
#   imarith (star//"k_clean", "/", "tell_k", "blackbody_k")

#removendo teluricas

#removing telluric lines

   print ("secZ do objeto:"//szobj)
   print ("secZ da estrela:"//szstar)

   telluric (outpre//"j_cut",
      outpre//"j_tell", "tell_j", szobj, "yes", ignoreaps=no, xcorr=yes,
      tweakrms=yes, interactive=yes, sample="*", threshold=.1, lag=10, shift=0.,
      scale=1., dshift=0.1, dscale=0.1, offset=1., smooth=1, cursor="")

   telluric (outpre//"h_cut",
      outpre//"h_tell", "tell_h", szobj, "yes", ignoreaps=no, xcorr=yes,
      tweakrms=yes, interactive=yes, sample="*", threshold=.1, lag=10, shift=0.,
      scale=1., dshift=0.1, dscale=0.1, offset=1., smooth=1, cursor="")

   telluric (outpre//"k_cut",
      outpre//"k_tell", "tell_k", szobj, "yes", ignoreaps=no, xcorr=yes,
      tweakrms=yes, interactive=yes, sample="*", threshold=.1, lag=10, shift=0.,
      scale=1., dshift=0.1, dscale=0.1, offset=1., smooth=1, cursor="")

#aplicando standard

#applying the standard task

   hedit ("blackbody_j", "OBSERVAT", "GEMINI-SOUTH", add=yes, addonly=yes, delete=no,
          verify=no, show=yes, update=yes)

   hedit ("blackbody_h", "OBSERVAT", "GEMINI-SOUTH", add=yes, addonly=yes, delete=no,
          verify=no, show=yes, update=yes)

   hedit ("blackbody_k", "OBSERVAT", "GEMINI-SOUTH", add=yes, addonly=yes, delete=no,
          verify=no, show=yes, update=yes)
   
   standard ("blackbody_j",
      "std", "J", szstar, expts, jmag, "J", "A0V", "yes", samestar=no, beam_switch=no,
      apertures="", bandwidth=INDEF, bandsep=INDEF, fnuzero=3.6800000000000E-20,
      extinction="", caldir="onedstds$blackbody/", observatory="gemini-south",
      interact=no, graphics="stdgraph", cursor="")

   standard ("blackbody_h",
      "std", "H", szstar, expts, hmag, "H", "A0V", "yes", samestar=no, beam_switch=no,
      apertures="", bandwidth=INDEF, bandsep=INDEF, fnuzero=3.6800000000000E-20,
      extinction=" ", caldir="onedstds$blackbody/", observatory="gemini-south",
      interact=no, graphics="stdgraph", cursor="")

   standard ("blackbody_k",
      "std", "K", szstar, expts, kmag, "K", "A0V", "yes", samestar=no, beam_switch=no,
      apertures="", bandwidth=INDEF, bandsep=INDEF, fnuzero=3.6800000000000E-20,
      extinction=" ", caldir="onedstds$blackbody/", observatory="gemini-south",
      interact=no, graphics="stdgraph", cursor="")

#aplicando sensfunc

#applying the sensfunc task

   sensfunc ("std",
      "sens", "yes", apertures="", ignoreaps=no, logfile="logfile", extinction="",
      newextinctio="extinct.dat", observatory="gemini-south", function="spline3",
      order=9, interactive=yes, graphs="sr", marks="plus cross box",
      colors="2 1 3 4", cursor="", device="stdgraph")

#aplicando a calibracao

#applying the flux calibration

   calibrate (outpre//"j_tell",
      outpre//"j_flux", szobj, expto, extinct=no, flux=yes,
      extinction="onedstds$ctioextinct.dat", observatory="gemini-south",
      ignoreaps=no, sensitivity="sens", fnu=no)

   calibrate (outpre//"h_tell",
      outpre//"h_flux", szobj, expto, extinct=no, flux=yes,
      extinction="onedstds$ctioextinct.dat", observatory="gemini-south",
      ignoreaps=no, sensitivity="sens", fnu=no)

   calibrate (outpre//"k_tell",
      outpre//"k_flux", szobj, expto, extinct=no, flux=yes,
      extinction="onedstds$ctioextinct.dat", observatory="gemini-south",
      ignoreaps=no, sensitivity="sens", fnu=no)

   print ("Fim!")

end
