#
# This script prepares the normalized flat 
# image for the doosiris task              
#
###############################################
#
# Modification table
#
# 05/18/2011 - Interactive apertured editing bug corrected
#            - Full table of necessary parameters for ap*
#            - Refined parameters for automatic aperture finding
#
#
#
#
#

procedure xdflat (prefix)
   
   string prefix		{prompt="Image name prefix"}
   bool   comb=yes              {prompt="Subtract and combine flat exposures?"}
   int    first			{prompt="First image number"}
   int    last			{prompt="Last image number"}
   string key="object"  	{prompt="Header keyword"}
   string keyon="xdflat-on"	{prompt="Value of keyword for flat on"}
   string keyoff="xdflat-off"	{prompt="Value of keyword for flat off"}
   string out1="flat"		{prompt="Name of subtracted flat"}
   bool   apflt=yes		{prompt="Normalize flat?"}
   string out2="Flat"		{prompt="Name of normalized flat"}
   string f_function="spline3"	{prompt="Flattening function"}
   real   f_order=30		{prompt="Order of the flattening function"}
   string apid="xdspres$xdap.tab" {prompt="Aperture identification table"}
   bool   inter=no		{prompt="Perform tasks interactively?"}

begin

   int n
   string zeros
   
   if(comb){
     
      for(n = first; n <= last; n+=1){
    
         if(n<10){zeros="000"}
         if(n>=10){
            if(n<100){zeros="00"}}
         if(n>=100){
            if(n<1000){zeros="0"}}
         if(n>=1000){zeros=""}
    
         s2 = ""
    
         hselect (prefix//zeros//n//".fits", key, "yes") | scan s1
         hselect (prefix//zeros//n//".fits", "lincor", "yes") | scan s2
         print (s1)
         
         if(s1 == keyon){
            print (prefix//zeros//n//".fits", >> "on.list")
            if(s2 != "yes"){
               irlincor (input=prefix//zeros//n//".fits", output=prefix//zeros//n//".fits", coeff1=1.00108,
                         coeff2=-3.328396e-2, coeff3=0.166216, coeff4=-6.844057e-2)
               hedit (prefix//zeros//n//".fits", "lincor", "yes", add=yes, addonly=yes, delete=no,
                      verify=no, show=yes, update=yes)
            }
            if(s2 == "yes"){
               print ("Image ",prefix//zeros//n//".fits"," already corrected.")
            }
         }
    
         if(s1 == keyoff){
            print (prefix//zeros//n//".fits", >> "off.list")
            if(s2 != "yes"){
               irlincor (input=prefix//zeros//n//".fits", output=prefix//zeros//n//".fits", coeff1=1.00108,
                         coeff2=-3.328396e-2, coeff3=0.166216, coeff4=-6.844057e-2)
               hedit (prefix//zeros//n//".fits", "lincor", "yes", add=yes, addonly=yes, delete=no,
                      verify=no, show=yes, update=yes)
            }
            if(s2 == "yes"){
               print ("Image ", prefix//zeros//n//".fits", " already corrected.")
            }
         }
      
   }
    
       
   imcombine("@"//"on.list", "flat_on.fits", combine="average", reject="minmax")
   imcombine("@"//"off.list", "flat_off.fits", combine="average", reject="minmax")
  
   imarith("flat_on.fits", "-", "flat_off.fits", out1)
    
   del("flat_on.fits")
   del("flat_off.fits")
   del("on.list")
   del("off.list")

   print ("###")
   print ("Flat-field images combined and subtracted.")
   print ("###")

   }
   
   if(apflt){
      
#
# Adjusting task parameters
#
      apdefault.lower = -40.0
      apdefault.upper = 40.0
      apdefault.apidtab = apid
#
      apedit.line = 500.0
      apedit.nsum = 10.0
      apedit.width = 80.0
      apedit.radius = 30.0
      apedit.threshold = 0.0
#
      apfind.line = 500.0
      apfind.nsum = 10.0
      apfind.minsep = 20.0
      apfind.maxsep = 1000.0
      apfind.order = "increasing"
#
      apresize.line = 500.0
      apresize.nsum = 10.0
      apresize.llimit = -60.0
      apresize.ulimit = 60.0
      apresize.ylevel = .25
      apresize.peak = yes
      apresize.bkg = no
#
      apfind (out1,
         3, apertures=" ", references="", interactive=yes, find=yes, recenter=yes,
         resize=yes, edit=inter, line=500, nsum=10, minsep=30., maxsep=1000.,
         order="increasing")
         
      aptrace (out1,
         apertures="1", references="", interactive=yes, find=no, recenter=no,
         resize=no, edit=no, trace=yes, fittrace=inter, line=500, nsum=5, step=5,
         nlost=5, function="legendre", order=2, sample="50:800", naverage=1,
         niterate=2, low_reject=2., high_reject=2., grow=0.)
         
      aptrace (out1,
         apertures="2", references="", interactive=yes, find=no, recenter=no,
         resize=no, edit=no, trace=yes, fittrace=inter, line=500, nsum=10, step=10,
         nlost=3, function="legendre", order=2, sample="50:950", naverage=1,
         niterate=2, low_reject=2., high_reject=2., grow=0.)

      aptrace (out1,
         apertures="3", references="", interactive=yes, find=no, recenter=no,
         resize=no, edit=no, trace=yes, fittrace=inter, line=500, nsum=10, step=10,
         nlost=3, function="legendre", order=2, sample="400:1000", naverage=1,
         niterate=2, low_reject=2., high_reject=2., grow=0.)

      apflatten (out1,
         out2, apertures="", references="", interactive=inter, find=no,
         recenter=no, resize=no, edit=no, trace=no, fittrace=no, flatten=yes,
         fitspec=yes, line=INDEF, nsum=10, threshold=10., pfit="fit1d", clean=yes,
         saturation=INDEF, readnoise="0.", gain="1.", lsigma=4., usigma=4.,
         function=f_function, order=f_order, sample="*", naverage=1, niterate=3,
         low_reject=3., high_reject=3., grow=0.)
  
      print ("###")
      print ("Flattening completed.")
      print ("You may proceed to the reduction process.")
      print ("Have a nice day!")
      print ("###")

   }

end

